@@ -20,6 +20,7 @@ class TuckERPyKeen(EntityRelationEmbeddingModelPyKeen):
         batch_size: int = 2**10,
         training_loop: Union[str, Type[TrainingLoop]
                              ] = "Stochastic Local Closed World Assumption",
+        verbose: bool = False,
         random_state: int = 42,
         enable_cache: bool = False
     ):
@@ -58,6 +59,8 @@ class TuckERPyKeen(EntityRelationEmbeddingModelPyKeen):
             Can either be:
             - Stochastic Local Closed World Assumption
             - Local Closed World Assumption
+        verbose: bool = False
+            Whether to show loading bars.
         random_state: int = 42
             Random seed to use while training the model
         enable_cache: bool = False
@@ -74,12 +77,13 @@ class TuckERPyKeen(EntityRelationEmbeddingModelPyKeen):
             epochs=epochs,
             batch_size=batch_size,
             training_loop=training_loop,
+            verbose=verbose,
             random_state=random_state,
             enable_cache=enable_cache
         )
 
     def parameters(self) -> Dict[str, Any]:
-        return {
+        return dict(
             **super().parameters(),
             **dict(
                 relation_dim=self._relation_dim,
@@ -88,7 +92,7 @@ class TuckERPyKeen(EntityRelationEmbeddingModelPyKeen):
                 dropout_2=self._dropout_2,
                 apply_batch_normalization=self._apply_batch_normalization
             )
-        }
+        )
 
     @classmethod
     def model_name(cls) -> str:
@@ -113,5 +117,6 @@ class TuckERPyKeen(EntityRelationEmbeddingModelPyKeen):
             dropout_0=self._dropout_0,
             dropout_1=self._dropout_1,
             dropout_2=self._dropout_2,
-            apply_batch_normalization=self._apply_batch_normalization
+            apply_batch_normalization=self._apply_batch_normalization,
+            random_seed=self._random_state
         )
