@@ -20,13 +20,12 @@ class RandomForestNodeLabelPrediction(SklearnNodeLabelPredictionAdapter):
         max_features="sqrt",
         max_leaf_nodes=None,
         min_impurity_decrease=0.,
-        min_impurity_split=None,
         bootstrap=True,
         oob_score=False,
         n_jobs=-1,
         verbose=0,
         warm_start=False,
-        class_weight=None,
+        class_weight="balanced",
         ccp_alpha=0.0,
         max_samples=None,
         random_state: int = 42
@@ -41,7 +40,6 @@ class RandomForestNodeLabelPrediction(SklearnNodeLabelPredictionAdapter):
         self._max_features = max_features
         self._max_leaf_nodes = max_leaf_nodes
         self._min_impurity_decrease = min_impurity_decrease
-        self._min_impurity_split = min_impurity_split
         self._bootstrap = bootstrap
         self._oob_score = oob_score
         self._n_jobs = cpu_count() if n_jobs == -1 else n_jobs
@@ -62,7 +60,6 @@ class RandomForestNodeLabelPrediction(SklearnNodeLabelPredictionAdapter):
                 max_features=max_features,
                 max_leaf_nodes=max_leaf_nodes,
                 min_impurity_decrease=min_impurity_decrease,
-                min_impurity_split=min_impurity_split,
                 bootstrap=bootstrap,
                 oob_score=oob_score,
                 n_jobs=n_jobs,
@@ -98,7 +95,6 @@ class RandomForestNodeLabelPrediction(SklearnNodeLabelPredictionAdapter):
                 max_features = self._max_features,
                 max_leaf_nodes = self._max_leaf_nodes,
                 min_impurity_decrease = self._min_impurity_decrease,
-                min_impurity_split = self._min_impurity_split,
                 bootstrap = self._bootstrap,
                 oob_score = self._oob_score,
                 n_jobs = self._n_jobs,
