@@ -121,6 +121,7 @@ def classification_evaluation_pipeline(
     repositories: Optional[Union[str, List[str]]] = None,
     versions: Optional[Union[str, List[str]]] = None,
     enable_cache: bool = False,
+    precompute_constant_automatic_stocastic_features: bool = False,
     smoke_test: bool = False,
     **evaluation_kwargs
 ) -> pd.DataFrame:
@@ -162,6 +163,15 @@ def classification_evaluation_pipeline(
         Graph versions to retrieve.
     enable_cache: bool = False
         Whether to enable the cache.
+    precompute_constant_automatic_stocastic_features: bool = False
+        Whether to precompute once the constant automatic stocastic
+        features before starting the embedding loop. This means that,
+        when left set to false, while the features will be computed
+        using the same input data, the random state between runs will
+        be different and therefore the experiment performance will
+        capture more of the variance derived from the stocastic aspect
+        of the considered method. When set to true, they are only computed
+        once and therefore the experiment will be overall faster.
     smoke_test: bool = False
         Whether this run should be considered a smoke test
         and therefore use the smoke test configurations for
@@ -184,6 +194,7 @@ def classification_evaluation_pipeline(
             number_of_holdouts=number_of_holdouts,
             random_state=random_state,
             enable_cache=enable_cache and not smoke_test,
+            precompute_constant_automatic_stocastic_features=precompute_constant_automatic_stocastic_features,
             smoke_test=smoke_test,
             **evaluation_kwargs
         )
